# Refer to document icons by their name rather than by number
icon = {
    "Document": 0,
    "Facebook": 1,
    "Linked In": 2,
    "Twitter": 3,
    "Map Pin": 4,
    "Globe": 5,
    "Enevelope": 6,
    "Phone": 7,
    "Speaker": 8,
    "Film Reel": 9,
    "Desktop": 10,
    "Chat": 11,
    "Map": 12,
    "Article": 13,
    "Gallery": 14,
    "Outbox": 15,
    "Linked In": 16,
    "Pin": 17,
    "Bar Graph": 18,
    "Paper Clip": 19,
    "Access Point": 20,
    "Calendar": 21,
    "Checkmark": 22,
    "Paper Plane": 23,
    "Star": 24,
    "Warning Triangle": 25,
    "Search": 26,
    "Folder": 27,
    "Inbox": 28,
    "Edit": 31,
    "People": 32,
    "Home": 37,
    "Home Search": 38,
    "Diner": 39,
    "Open Sign": 40,
    "Info Circle": 41,
    "Help Circle": 42,
    "Flag": 43,
    "Wine Glass": 44,
    "Cocktail": 45,
    "Coffee": 46,
    "News": 47,
    "Car": 48,
    "Office Building": 49,
    "Info Square": 52,
    "Globe Search": 53,
    "Alarm Clock": 54,
    "Guitar": 55,
    "Road Signs": 56,
    "Wifi Tablet": 57,
    "Open Book": 58,
    "X Box": 62,
    "Gear": 64,
    "Log out": 65,
    "Instagram": 68,
    "Google Plus": 69,
    "Hashtag": 70,
    "Back": 71,
    "Forward": 72,
    "Refresh": 73,
    "Document Stamp": 75,
    "Alarm Bell": 77,
    "Alarm Bell Cog": 78,
}
